#!/usr/bin/env python
import boto
import sys


def main():
    s3 = boto.connect_s3()
    bucket = s3.get_bucket('tablesnap-unittest')
    keys = bucket.get_all_keys()

    if not keys:
        print 'TEST FAIL No keys found in test bucket!'
        return 1
    else:
        print 'TEST PASS Tablesnap created S3 keys successfully!'

    bucket.delete_keys(keys)
    return 0


if __name__ == '__main__':
    sys.exit(main())



from setuptools import setup

setup(
    name='tablesnap',
    version='0.7.3',
    author='Jeremy Grosser',
    author_email='jeremy@synack.me',
    url='https://github.com/JeremyGrosser/tablesnap',
    scripts=[
        'tablesnap',
        'tableslurp',
        'tablechop'
    ],
    install_requires=[
        'pyinotify',
        'boto>=2.6.0',
        'argparse',
        'python-dateutil',
    ],
)
